16.73. cdist-type__install_umount(7) — cdist 4.11.0 documentation

# 16.73. cdist-type__install_umount(7)

## 16.73.1. NAME

cdist-type__install_umount - umount target directory

## 16.73.2. DESCRIPTION

This cdist type allows you to recursively umount the given target directory.

## 16.73.3. REQUIRED PARAMETERS

None

## 16.73.4. OPTIONAL PARAMETERS

target
  the mount point to umount. Defaults to object_id

## 16.73.5. EXAMPLES

    __install_umount /target

## 16.73.6. AUTHORS

Steven Armstrong <steven-cdist--@--armstrong.cc>

## 16.73.7. COPYING

Copyright (C) 2011 Steven Armstrong. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.